@@ -24,9 +24,7 @@
 #include "variablesdelegate.h"
 #include "viewportwidget.h"
 #include "functionedit.h"
-#ifdef HAVE_OPENGL
-#    include <analitzagui/plotsview3d.h>
-#endif
+#include <analitzagui/plotsview3d_es.h>
 
 #include <analitzagui/operatorsmodel.h>
 #include <analitzagui/expressionedit.h>
@@ -80,7 +78,6 @@ class Add2DOption : public InlineOptions
         KAlgebra* m_kalgebra;
 };
 
-#ifdef HAVE_OPENGL
 class Add3DOption : public InlineOptions
 {
     public:
@@ -101,7 +98,6 @@ class Add3DOption : public InlineOptions
     private:
         KAlgebra* m_kalgebra;
 };
-#endif
 
 QColor randomFunctionColor() { return QColor::fromHsv(qrand()%255, 255, 255); }
 
@@ -290,14 +286,13 @@ KAlgebra::KAlgebra(QWidget *parent)
     //////EO2D Graph
     
     /////3DGraph
-#ifdef HAVE_OPENGL
     QWidget *tridim = new QWidget(m_tabs);
     QVBoxLayout *t_layo = new QVBoxLayout(tridim);
     t_exp = new Analitza::ExpressionEdit(tridim);
     t_exp->setExamples(Analitza::PlotsFactory::self()->examples(Analitza::Dim3D));
     t_exp->setAns(QStringLiteral("x"));
     t_model3d = new Analitza::PlotsModel(this);
-    m_graph3d = new Analitza::PlotsView3D(tridim);
+    m_graph3d = new Analitza::PlotsView3DES(tridim);
     m_graph3d->setModel(t_model3d);
     m_graph3d->setUseSimpleRotation(true);
     
@@ -313,7 +308,7 @@ KAlgebra::KAlgebra(QWidget *parent)
     t_menu = menuBar()->addMenu(i18n("3D &Graph"));
     QAction* t_actions[5];
     t_menu->addAction(KStandardAction::save(this, SLOT(save3DGraph()), this));
-    t_menu->addAction(QIcon::fromTheme(QStringLiteral("zoom-original")), i18n("&Reset View"), m_graph3d, SLOT(resetView()));
+    t_menu->addAction(QIcon::fromTheme(QStringLiteral("zoom-original")), i18n("&Reset View"), m_graph3d, [this]() { m_graph3d->resetView(); });
     t_menu->addSeparator();
     t_actions[2] = t_menu->addAction(i18n("Dots"), this, SLOT(set_dots()));
     t_actions[3] = t_menu->addAction(i18n("Lines"), this, SLOT(set_lines()));
@@ -328,7 +323,7 @@ KAlgebra::KAlgebra(QWidget *parent)
     t_actions[3]->setCheckable(true);
     t_actions[4]->setCheckable(true);
     t_actions[4]->setChecked(true);
-#endif
+
     ////////////
     //////EO3D Graph
     menuBar()->addMenu(QStringLiteral("|"))->setEnabled(false);
@@ -538,7 +533,6 @@ void KAlgebra::set_res_vfine()    { b_funcsModel->setResolution(3328);}
 
 void KAlgebra::new_func3d()
 {
-#ifdef HAVE_OPENGL
     Analitza::Expression exp = t_exp->expression();
     Analitza::PlotBuilder plot = Analitza::PlotsFactory::self()->requestPlot(exp, Analitza::Dim3D, c_results->analitza()->variables());
     if(plot.canDraw()) {
@@ -546,39 +540,31 @@ void KAlgebra::new_func3d()
         t_model3d->addPlot(plot.create(Qt::yellow, QStringLiteral("func3d")));
     } else
         changeStatusBar(i18n("Errors: %1", plot.errors().join(i18n(", "))));
-#endif
 }
 
 void KAlgebra::set_dots()
 {
-#ifdef HAVE_OPENGL
     m_graph3d->setPlotStyle(Analitza::Dots);
-#endif
 }
 
 void KAlgebra::set_lines()
 {
-#ifdef HAVE_OPENGL
     m_graph3d->setPlotStyle(Analitza::Wired);
-#endif
 }
 
 void KAlgebra::set_solid()
 {
-#ifdef HAVE_OPENGL
     m_graph3d->setPlotStyle(Analitza::Solid);
-#endif
 }
 
 void KAlgebra::save3DGraph()
 {
-#ifdef HAVE_OPENGL
     QString path = QFileDialog::getSaveFileName(this, QString(), QString(), i18n("PNG File (*.png);;PDF Document(*.pdf);;X3D Document (*.x3d);;STL Document (*.stl)"));
     if(!path.isEmpty()) {
         if(path.endsWith(QLatin1String(".x3d")) || path.endsWith(QLatin1String(".stl"))) {
             m_graph3d->exportSurfaces(path);
         } else if(path.endsWith(QLatin1String(".pdf"))) {
-            QPixmap px = m_graph3d->renderPixmap();
+            auto px = m_graph3d->grabFramebuffer();
             QPrinter printer;
             printer.setOutputFormat(QPrinter::PdfFormat);
             printer.setOutputFileName(path);
@@ -586,14 +572,13 @@ void KAlgebra::save3DGraph()
             printer.setPageMargins(0,0,0,0, QPrinter::DevicePixel);
             QPainter painter;
             painter.begin(&printer);
-            painter.drawPixmap(QPoint(0,0), px);
+            painter.drawImage(QPoint(0,0), px);
             painter.end();
         } else {
-            QPixmap px = m_graph3d->renderPixmap();
+            auto px = m_graph3d->grabFramebuffer();
             px.save(path);
         }
     }
-#endif
 }
 
 void KAlgebra::toggleSquares()
@@ -638,9 +623,8 @@ void KAlgebra::tabChanged(int n)
     
     menuEnabledHelper(c_menu, n==0);
     menuEnabledHelper(b_menu, n==1);
-#ifdef HAVE_OPENGL
     menuEnabledHelper(t_menu, n==2);
-#endif
+
     m_status->clear();
     
     switch(n) {
@@ -657,11 +641,9 @@ void KAlgebra::tabChanged(int n)
                 b_tools->setCurrentIndex(1); //We set the Add tab
 //             b_add->setFocus();
             break;
-#ifdef HAVE_OPENGL
         case 2:
             t_exp->setFocus();
             break;
-#endif
         case 3:
             d_filter->setFocus();
             d_dock->show();
@@ -718,13 +700,11 @@ void KAlgebra::varsContextMenu(const QPoint& p)
 
 void KAlgebra::add3D(const Analitza::Expression& exp)
 {
-#ifdef HAVE_OPENGL
     t_model3d->clear();
     Analitza::PlotBuilder plot = Analitza::PlotsFactory::self()->requestPlot(exp, Analitza::Dim3D, c_results->analitza()->variables());
     Q_ASSERT(plot.canDraw());
     t_model3d->addPlot(plot.create(Qt::yellow, QStringLiteral("func3d_console")));
     m_tabs->setCurrentIndex(2);
-#endif
 }
 
 void KAlgebra::dictionaryFilterChanged(const QString&)
